#!/usr/bin/python
import psycopg2
from configparser import ConfigParser
from dotenv import load_dotenv

class connection():

    def config_db(filename='/database.ini', section='postgresql'):
        # create a parser
        parser = ConfigParser()
        # read config file
        parser.read(filename)

        # get section, default to postgresql
        db = {}
        if parser.has_section(section):
            params = parser.items(section)
            for param in params:
                db[param[0]] = param[1]
        else:
            raise Exception('Section {0} not found in the {1} file'.format(section, filename))

        return db

    def connect():
        """ Connect to the PostgreSQL database server """
        conn = None
        try:
            # read connection parameters
            params = connection.config_db()

            # connect to the PostgreSQL server
            print('Connecting to the PostgreSQL database...')
            conn = psycopg2.connect(**params)

            # create a cursor
            cur = conn.cursor()

            # execute a statement
            print('PostgreSQL database version:')
            cur.execute('SELECT version()')

            # display the PostgreSQL database server version
            db_version = cur.fetchone()
            print(db_version)

            # close the communication with the PostgreSQL
            cur.close()
        except (Exception, psycopg2.DatabaseError) as error:
            print(error)
        finally:
            if conn is not None:
                conn.close()
                print('Database connection closed.')


    def dbengine():
        conn = None
        try:
            # read connection parameters
            conn = psycopg2.connect(
                database    = os.getenv('DATABASE_NAME'), 
                user        = os.getenv('DB_USERNAME'), 
                password    = os.getenv('DB_PASSWORD'), 
                host        = os.getenv('DB_HOST'), 
                port        = os.getenv('DB_PORT')
            )

        except (Exception, psycopg2.DatabaseError) as error:
            print(error)
        finally:
            if conn is not None:
                return conn

        return conn


# if __name__ == '__main__':
#     connection.connect()