from flask import Blueprint, request, url_for
from flask_mail import Message
from itsdangerous import URLSafeTimedSerializer
from app import db, mail, serializer
from app.models.user import User
from app.utils.response import success_response, error_response

email_bp = Blueprint('email', __name__)

def send_reset_email(user):
    token = serializer.dumps(user.email, salt='password-reset-salt')
    reset_url = url_for('email.reset_password', token=token, _external=True)
    msg = Message("Password Reset Request",
                  sender='noreply@demo.com',
                  recipients=[user.email])
    msg.body = f"""To reset your password, visit the following link:
{reset_url}

If you did not make this request then simply ignore this email and no changes will be made.
"""
    mail.send(msg)

@email_bp.route('/reset_password_request', methods=['POST'])
def reset_password_request():
    data = request.json
    email = data.get('email')
    
    user = User.query.filter_by(email=email).first()
    if user:
        send_reset_email(user)
    return success_response(message="If an account with that email exists, you will receive an email with instructions to reset your password.")

@email_bp.route('/reset_password/<token>', methods=['POST'])
def reset_password(token):
    try:
        email = serializer.loads(token, salt='password-reset-salt', max_age=3600)
    except:
        return error_response("The reset link is invalid or has expired.", code=400)

    data = request.json
    password = data.get('password')
    
    user = User.query.filter_by(email=email).first()
    if user:
        user.set_password(password)
        db.session.commit()
        return success_response(message="Your password has been updated!")
    return error_response("Invalid email address.", code=400)
